/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */
define(["require","exports"],(function(E,e){"use strict";Object.defineProperty(e,"__esModule",{value:!0}),function(E){E[E.ENTER=13]="ENTER",E[E.ESCAPE=27]="ESCAPE",E[E.SPACE=32]="SPACE",E[E.END=35]="END",E[E.HOME=36]="HOME",E[E.LEFT=37]="LEFT",E[E.UP=38]="UP",E[E.RIGHT=39]="RIGHT",E[E.DOWN=40]="DOWN"}(e.KeyTypesEnum||(e.KeyTypesEnum={}))}));